ReadConfig

Struct ReadConfig 

pub struct ReadConfig {
    pub read_meta_items: bool,
    pub read_image_data: bool,
    pub read_chapter_list: bool,
    pub read_chapter_track: bool,
    pub read_audio_info: bool,
    pub chpl_timescale: ChplTimescale,
}
Configure what kind of data should be rad

The item list stores tags such as the artist, album, title, and also the cover art of a song. And there are two separate ways of storing chapter information:

  • A chapter list
  • A chapter track

Fields

read_meta_items: bool

Wheter the metatdata item list will be read.

read_image_data: bool

Wheter image data will be read, mostly for performance reasons. If disabled, images will still show up as empty Data.

read_chapter_list: bool

Wheter chapter list information will be read.

read_chapter_track: bool

Wheter chapter track information will be read.

read_audio_info: bool

Wheter audio information will be read. Even if disabled, the AudioInfo::duration will be read.

chpl_timescale: ChplTimescale

The timescale that is used to scale time for chapter list (chpl) atoms.

Implementations

Source

impl ReadConfig

pub const DEFAULT: ReadConfig

The default configuration for reading tags.

pub const NONE: ReadConfig

A configuration that would read no data at all.

use mp4ameta::ReadConfig;

let cfg = ReadConfig {
    read_meta_items: true,
    read_image_data: true,
    ..ReadConfig::NONE
};